# TODO

- [x] use <https://github.com/actions/attest-build-provenance> for all assets
- [ ] Badges for settings.publishing section

## annotations for each job

- [ ] mypy
- [ ] ruff
- [ ] ruff formatting when Python support >= 3.12
- [ ] yapf (equivalent to yapf-gitlab)

## Code signing

- sign macOS binaries
- sign Windows binaries

### Links

- <https://github.com/marketplace/actions/code-sign-action>
- <https://github.com/ddev/signing_tools>
- <https://github.com/anchore/quill>
- <https://github.com/mtrojnar/osslsigncode> (available from msys2)
- <https://certum.store/open-source-code-signing-on-simplysign.html>
- <https://learn.microsoft.com/en-us/azure/trusted-signing/concept-trusted-signing-resources-roles>
- <https://github.com/spyoungtech/helldivers2-macros/blob/a5e9c18331dafa33a909436626fa9a8264a8ea18/.github/workflows/release.yaml#L33-L92>
